==> gramps-5.2.4.tgz: lib/python3.12/site-packages/gramps/gen/filters/rules/place/_hastitle.py <==
#
# Gramps - a GTK+/GNOME based genealogy program
#
# Copyright (C) 2002-2006  Donald N. Allingham
# Copyright (C) 2015       Nick Hall
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
#

# -------------------------------------------------------------------------
#
# Standard Python modules
#
# -------------------------------------------------------------------------
from ....const import GRAMPS_LOCALE as glocale

_ = glocale.translation.sgettext

# -------------------------------------------------------------------------
#
# Gramps modules
#
# -------------------------------------------------------------------------
from .. import Rule
from ....display.place import displayer


# -------------------------------------------------------------------------
#
# HasTitle
#
# -------------------------------------------------------------------------
class HasTitle(Rule):
    """
    Rule that checks for a place with a title
    """

    labels = [_("Title:")]
    name = _("Places matching a title")
    description = _("Matches places with a particular title")
    category = _("General filters")
    allow_regex = True

    def apply(self, db, place):
        if not self.match_substring(0, displayer.display(db, place)):
            return False
        return True

==> gramps-6.0.6.tgz: lib/python3.13/site-packages/gramps/gen/filters/rules/place/_hastitle.py <==
#
# Gramps - a GTK+/GNOME based genealogy program
#
# Copyright (C) 2002-2006  Donald N. Allingham
# Copyright (C) 2015       Nick Hall
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, see <https://www.gnu.org/licenses/>.
#

# -------------------------------------------------------------------------
#
# Standard Python modules
#
# -------------------------------------------------------------------------
from ....const import GRAMPS_LOCALE as glocale

_ = glocale.translation.sgettext

# -------------------------------------------------------------------------
#
# Gramps modules
#
# -------------------------------------------------------------------------
from .. import Rule
from ....display.place import displayer


# -------------------------------------------------------------------------
#
# Typing modules
#
# -------------------------------------------------------------------------
from ....lib import Place
from ....db import Database


# -------------------------------------------------------------------------
#
# HasTitle
#
# -------------------------------------------------------------------------
class HasTitle(Rule):
    """
    Rule that checks for a place with a title
    """

    labels = [_("Title:")]
    name = _("Places matching a title")
    description = _("Matches places with a particular title")
    category = _("General filters")
    allow_regex = True

    def apply_to_one(self, db: Database, place: Place) -> bool:
        if not self.match_substring(0, displayer.display(db, place)):
            return False
        return True
